==> haskell-rvar-0.3.0.2-23-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-rvar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 rvar
version:              0.3.0.2
visibility:           public
id:                   rvar-0.3.0.2-3Xs1WNofx5FBJwhMQGG0On
key:                  rvar-0.3.0.2-3Xs1WNofx5FBJwhMQGG0On
license:              LicenseRef-PublicDomain
maintainer:           Dominic Steinitz <dominic@steinitz.org>
author:               James Cook <mokus@deepbondi.net>
stability:            stable
homepage:             https://github.com/haskell-numerics/random-fu
synopsis:             Random Variables
description:
    Random number generation based on modeling random
    variables by an abstract type ('\''RVar'\'') which can be
    composed and manipulated monadically and sampled in
    either monadic or \"pure\" styles.

    The primary purpose of this library is to support
    defining and sampling a wide variety of high quality
    random variables.  Quality is prioritized over speed,
    but performance is an important goal too.

    In my testing, I have found it capable of speed
    comparable to other Haskell libraries, but still
    a fair bit slower than straight C implementations of
    the same algorithms.

category:             Math
abi:                  7b2cca54201d0b53cc059f58449e4470
exposed:              True
exposed-modules:      Data.RVar
hidden-modules:       Data.RVar.Prim
import-dirs:          /usr/lib/ghc-9.2.8/site-local/rvar-0.3.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/rvar-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rvar
hs-libraries:         HSrvar-0.3.0.2-3Xs1WNofx5FBJwhMQGG0On
depends:
    MonadPrompt-1.0.0.5-2LatcwGGS2Q5uLEuFYBrfY base-4.16.4.0
    bytestring-0.11.4.0 mtl-2.2.2 random-1.2.1.2-JIamRYdFYdY4e3nutT9Pr4
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-rvar/html/rvar.haddock
haddock-html:         /usr/share/doc/haskell-rvar/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rvar-0.3.0.2-25-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-rvar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 rvar
version:              0.3.0.2
visibility:           public
id:                   rvar-0.3.0.2-8bcsap70GYYJBbDHOqEaAe
key:                  rvar-0.3.0.2-8bcsap70GYYJBbDHOqEaAe
license:              LicenseRef-PublicDomain
maintainer:           Dominic Steinitz <dominic@steinitz.org>
author:               James Cook <mokus@deepbondi.net>
stability:            stable
homepage:             https://github.com/haskell-numerics/random-fu
synopsis:             Random Variables
description:
    Random number generation based on modeling random
    variables by an abstract type ('\''RVar'\'') which can be
    composed and manipulated monadically and sampled in
    either monadic or \"pure\" styles.

    The primary purpose of this library is to support
    defining and sampling a wide variety of high quality
    random variables.  Quality is prioritized over speed,
    but performance is an important goal too.

    In my testing, I have found it capable of speed
    comparable to other Haskell libraries, but still
    a fair bit slower than straight C implementations of
    the same algorithms.

category:             Math
abi:                  937c58bf07f539cd19f3a481b8305f00
exposed:              True
exposed-modules:      Data.RVar
hidden-modules:       Data.RVar.Prim
import-dirs:          /usr/lib/ghc-9.2.8/site-local/rvar-0.3.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/rvar-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rvar
hs-libraries:         HSrvar-0.3.0.2-8bcsap70GYYJBbDHOqEaAe
depends:
    MonadPrompt-1.0.0.5-2LatcwGGS2Q5uLEuFYBrfY base-4.16.4.0
    bytestring-0.11.4.0 mtl-2.2.2 random-1.2.1.2-BXSdRxlC6g4I8lxfKC5NFh
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-rvar/html/rvar.haddock
haddock-html:         /usr/share/doc/haskell-rvar/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
